import { Request, Response, NextFunction } from 'express';
import { AppError } from '../shared/AppError';
import jwt from 'jsonwebtoken';
import { prisma } from '../utils/prisma';

interface IPayload {
  sub: string;
}

const authenticationMiddleware = async (request: Request, response: Response, next: NextFunction) => {
  const { authorization } = request.headers;

  if (!authorization) {
    return new AppError(401, "Usuário não autorizado!").execute(response);
  }

  const [, token] = authorization.split(" ");

  try {
    const { sub: user_id } = jwt.verify(
      token,
      process.env.JWT_SECRET
    ) as IPayload;

    const user = await prisma.user.findUnique({
      where: {
        id: user_id
      }
    });

    if (!user) {
      return new AppError(400, "Usuário não encontrado!").execute(response);
    }

    request.user = {
      id: user_id,
      role: user.role
    }

    // Autenticado com sucesso
    return next();
  } catch {
    return new AppError(401, "Token inválido!").execute(response);
  }
};

export { authenticationMiddleware };