import React, { InputHTMLAttributes, useCallback } from 'react';
import { ABBRMask, CPFMask } from '../../utils/masks';

interface InputProps extends InputHTMLAttributes<HTMLInputElement> {
  label: string;
  mask?: "CPF" | "ABBR";
  error?: string;
  inputAddClasses?: string;
}

function Input({ mask, label, error, inputAddClasses, ...props }: InputProps) {

  const handleKeyUp = useCallback((event: React.FormEvent<HTMLInputElement>) => {
    if (mask && mask === "CPF") {
      CPFMask(event);
    }

    if (mask && mask === "ABBR") {
      ABBRMask(event);
    }

  }, []);

  return (
    <>
      <label className="block mb-1" htmlFor={props.id || ""}>{label}</label>
      <input
        {...props}
        className={`${inputAddClasses || "py-2 px-3"} border border-gray-300 focus:border-cyan-300 focus:outline-none focus:ring focus:ring-cyan-200 focus:ring-opacity-50 rounded-md shadow-sm disabled:bg-gray-100 mt-1 block w-full ${error ? "border-red-500" : "border-gray-300"} `}
        onKeyUp={handleKeyUp}
      />
      {error && (
        <span className="text-red-500 text-xs italic">{error}</span>
      )}
    </>
  );
}

export { Input };