import { SelectHTMLAttributes } from 'react';

interface InputProps extends SelectHTMLAttributes<HTMLSelectElement> {
  label: string;
  error?: string;
  options: {
    key: string;
    value: string;
  }[];
  textDefault: string;
  selectAddClasses?: string;
}

function Select({ label, error, options, textDefault, selectAddClasses, ...props }: InputProps) {
  return (
    <>
      <label className="block" htmlFor={props.id || ""}>{label}</label>
      <div className="inline-block relative w-full">
        <select
          {...props}
          className={`appearance-none leading-tight ${selectAddClasses || "py-2.5 px-3"} border border-gray-300 focus:border-cyan-300 focus:outline-none focus:ring focus:ring-cyan-200 focus:ring-opacity-50 rounded-md shadow-sm disabled:bg-gray-100 mt-1 block w-full ${error ? "border-red-500" : "border-gray-300"} `}
        >
          <option className='text-gray-600' value="default">{textDefault}</option>
          {options.map(option => {
            return (
              <option key={option.key} value={option.key}>{option.value}</option>
            );
          })
          }
        </select>
        <div className="pointer-events-none absolute inset-y-0 right-0  top-2 flex items-center mx-2 text-gray-500">
          <svg className="fill-current h-4 w-4" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20"><path d="M9.293 12.95l.707.707L15.657 8l-1.414-1.414L10 10.828 5.757 6.586 4.343 8z" /></svg>
        </div>
      </div>
      {error && (
        <span className="text-red-500 text-xs italic">{error}</span>
      )}
    </>
  );
}

export { Select };