import { IdentificationCard, List, Pill, Polygon, SquaresFour, UsersThree } from "phosphor-react";
import { useEffect } from "react";
import { useAuth } from "../../context/AuthContext";
import { useDimensionsScreen } from "../../utils/useDimensionsScreen";
import { SidebarItem } from "../SidebarItem";
import { SidebarSubItem } from "../SidebarSubItem";

interface SidebarProps {
  handleOpenSidebar: () => void;
  isOpen: boolean;
  setIsOpen: (isOpen: boolean) => void;
}

function Sidebar({ handleOpenSidebar, isOpen, setIsOpen }: SidebarProps) {
  const { width } = useDimensionsScreen();
  const { signOut, user } = useAuth();

  useEffect(() => {
    if (width <= 768) {
      setIsOpen(false);
    } else {
      setIsOpen(true);
    }
  }, [width]);

  // Sair da aplicação e voltar para a tela de login
  const handleSignOut = () => {
    signOut();
  }

  return (
    <nav className="relative">
      <div className={isOpen ? "w-screen mm:w-[250px] bg-gray-900 h-full z-50 md:block" : "relative w-[250px] bg-gray-900 md:h-full hidden md:block"}>
        <div className="px-6 pt-4">
          <div className="flex items-center justify-center">
            <a
              href="/dashboard"
              className="bg-blue-600 px-4 py-2 rounded flex items-center justify-center focus:outline-none focus:ring-1 focus:ring-blue-500 focus:ring-offset-2 focus:ring-offset-gray-900 text-white"
            >ESF Dourados MS</a>
          </div>
        </div>

        <div className="px-6 pt-4">
          <hr className="border-gray-700" />
        </div>
        <div className="px-6 pt-4">
          <ul className="flex flex-col space-y-2">
            <SidebarItem
              name="Painel"
              url="/dashboard"
              icon={<SquaresFour />}
            />
            {user?.role === "ADMIN" && (
              <SidebarItem
                name="Agentes"
                url="/agents"
                icon={<IdentificationCard />}
              >
                <SidebarSubItem name="Criar novo agente" url="create" />
                <SidebarSubItem name="Lista de agentes" url="list" />
                <SidebarSubItem name="Atualizar agente" url="update" hidden={true} />
              </SidebarItem>
            )}

            {user?.role === "ADMIN" && (
              <SidebarItem
                name="Condições de saúde"
                url="/conditions"
                icon={<Pill />}
              >
                <SidebarSubItem name="Criar condição de saúde" url="create" />
                <SidebarSubItem name="Condições de saúde" url="list" />
                <SidebarSubItem name="Atualizar condição de saúde" url="update" hidden={true} />
              </SidebarItem>
            )}

            {user?.role === "ADMIN" && (
              <SidebarItem
                name="Microáreas"
                url="/microareas"
                icon={<Polygon />}
              >
                <SidebarSubItem name="Criar microárea" url="create" />
                <SidebarSubItem name="Lista de microáreas" url="list" />
              </SidebarItem>
            )}

            {/*Ser acessiver para ambos os usuários*/}
            <SidebarItem
              name="Pacientes"
              url="/patients"
              icon={<UsersThree size={32} />}
            >
              {/* Apenas o ADMIN terá a opção de desativar um paciente */}
              <SidebarSubItem name="Cadastro de Pacientes" url="create" />
              <SidebarSubItem name="Lista de Pacientes" url="list" />

              {user?.role === "ADMIN" && (
                <SidebarSubItem name="Busca por Pacientes" url="search" />
              )}
            </SidebarItem>
          </ul>
        </div>
        <div className="px-6 pt-8">
          <hr className="border-gray-700" />
        </div>
        <div className="px-6 pt-4 pb-8">
          <button
            onClick={handleSignOut}
            className="btn_error w-full text-gray-200 hover:text-white focus:text-white"
          >
            Sair
          </button>
        </div>
      </div>

      <button className="w-8 h-8 fixed top-4 right-4 z-[100] md:hidden" onClick={handleOpenSidebar}>
        <List size={32} className={isOpen ? 'text-gray-300' : 'text-gray-800'} />
      </button>
    </nav>
  );

}

export { Sidebar };