import { NavLink, useMatch, useResolvedPath } from "react-router-dom";
import { CaretDown, IconProps } from 'phosphor-react';
import React, { Children, cloneElement, FunctionComponent, PropsWithChildren, ReactElement, ReactNode, useState } from "react";
import { SidebarSubItem, SidebarSubItemProps } from "../SidebarSubItem";

interface SidebarProps {
  name: string;
  url: string;
  icon: ReactElement;
  children?: ReactNode;
}

interface SidebarItemCompositionChildren {
  SidebarSubItem: FunctionComponent;
}

function SidebarItem({ name, url, icon, children }: SidebarProps) {
  const resolved = useResolvedPath(url);
  const match = useMatch({ path: resolved.pathname, end: true });
  const [matchChildren, setMatchChildren] = useState(false);
  const [openOptions, setOpenOptions] = useState(false);

  const iconProps = {
    size: 24
  } as IconProps;
  return (
    <>
      {!!!children
        ? (
          <li className={match ? "relative text-white flex justify-center items-center outline-none ring-1 ring-gray-500 bg-gray-800 rounded py-2 pr-4" : "relative text-gray-500 flex justify-center items-center hover:text-white focus-within:text-white rounded hover:bg-gray-800 focus:outline-none focus:ring-1 focus:ring-gray-500 focus:bg-gray-800 py-2 pr-4"}>
            <div
              className="flex items-center pl-2 pointer-events-none"
            >
              {cloneElement(icon, { ...iconProps })}
            </div>

            <NavLink
              to={url}
              className={({ isActive }) => isActive ? "inline-block w-full text-sm ml-1" : "inline-block w-full text-sm ml-1"}
            >
              {name}
            </NavLink>
          </li>
        )
        : (
          <li>
            <button
              className="w-full"
              onClick={() => {
                setOpenOptions(!openOptions);
              }}
            >
              <div className={matchChildren ? "relative text-white flex justify-center items-center outline-none ring-1 ring-gray-500 bg-gray-800 rounded py-2 pr-4" : "relative text-gray-500 flex justify-center items-center hover:text-white focus-within:text-white rounded hover:bg-gray-800 focus:outline-none focus:ring-1 focus:ring-gray-500 focus:bg-gray-800 py-2 pr-4"}>
                <div className="flex-1 flex items-center">
                  <div
                    className="flex items-center pl-2 pointer-events-none"
                  >
                    {cloneElement(icon, { ...iconProps })}
                  </div>

                  <span
                    className={matchChildren ? "inline-block text-sm ml-1" : "inline-block text-sm ml-1"}
                  >
                    {name}
                  </span>
                </div>
                <div className="flex items-center">
                  <CaretDown size={20} />
                </div>
              </div>
            </button>

            {openOptions && (
              <div className="pt-2 pl-4">
                <ul className="flex flex-col pl-2 text-gray-500 border-l border-gray-700 space-y-1">
                  {
                    Children.map(children, (child) => {
                      const subItem = child as ReactElement<PropsWithChildren<SidebarSubItemProps>>;

                      if (subItem?.type === SidebarSubItem) {
                        return cloneElement(subItem, { urlparent: url, handlematch: setMatchChildren });
                      } else {
                        return child
                      }
                    })
                  }
                </ul>
              </div>
            )}
          </li>
        )
      }
    </>
  );
}

export { SidebarItem };