import { FunctionComponent, useEffect } from "react";
import { Link, useLocation, useParams, useResolvedPath } from "react-router-dom";

export interface SidebarSubItemProps {
  name: string;
  url: string;
  urlparent?: string;
  handlematch?: (match: boolean) => void;
  hidden?: boolean
}

const SidebarSubItem: FunctionComponent<SidebarSubItemProps> = ({ name, url, urlparent, handlematch, hidden }) => {
  const { id } = useParams();
  const resolved = useResolvedPath(`${urlparent}/${url}`);
  const location = useLocation();
  useEffect(() => {
    if (handlematch) {

      let hasMatch;

      if (id) {
        hasMatch = location.pathname === `${resolved.pathname}/${id}`
      } else {
        hasMatch = location.pathname === resolved.pathname
      }

      if (hasMatch)
        handlematch(hasMatch);
    }
  }, [location])

  return (
    <li>
      <Link
        to={`${urlparent}/${url}`}
        className={`inline-block w-full px-4 py-2 text-xs rounded hover:bg-gray-800 hover:text-white focus:outline-none focus:ring-1 focus:ring-gray-500 focus:text-white ${hidden ? 'hidden' : ''}`}
      >{name}
      </Link>
    </li>
  );
}

export { SidebarSubItem };