import { TextareaHTMLAttributes } from 'react';

interface InputProps extends TextareaHTMLAttributes<HTMLTextAreaElement> {
  label: string;
  error?: string;
  resize?: boolean;
}

function Textarea({ label, error, resize, ...props }: InputProps) {
  return (
    <>
      <label className="block mb-1" htmlFor={props.id || ""}>{label}</label>
      <textarea
        {...props}
        className={`h-20 py-2 px-3 border border-gray-300 focus:border-cyan-300 focus:outline-none focus:ring focus:ring-cyan-200 focus:ring-opacity-50 rounded-md shadow-sm disabled:bg-gray-100 mt-1 block w-full ${error ? "border-red-500" : "border-gray-300"} ${resize && "resize-none"}`}
      ></textarea>
      {error && (
        <span className="text-red-500 text-xs italic">{error}</span>
      )}
    </>
  );
}

export { Textarea };