import pdfMake from "pdfmake/build/pdfmake";
import pdfFonts from "pdfmake/build/vfs_fonts";
import { TDocumentDefinitions } from "pdfmake/interfaces";
import { calculateAge } from "../../utils/calculateAge";
import { CPFMaskToView } from "../../utils/masks";

interface Patient {
  id: string;
  name: string;
  cpf: string;
  birthdate: string;
  sex: string;
  microarea: number,
  localization: {
    latitude: number,
    longitude: number,
  },
  conditions: {
    id: string;
    abbr: string;
  }[]
}

function patientReportPDF(patients: Patient[]) {
  /* Configurando Fonts */
  pdfMake.vfs = pdfFonts.pdfMake.vfs;

  /*Titulo do relatório*/
  const reportTitle = [
    {
      text: "Relatório de Pacientes",
      fontSize: 18,
      bold: true,
      margin: [15, 20, 0, 45] /*left, top, right, bottom*/
    }
  ] as TDocumentDefinitions["content"];


  const data = patients.map(patient => {
    let conditions: string = '';
    patient.conditions.forEach(condition => {
      conditions += condition.abbr + ", ";
    })

    return [
      { text: CPFMaskToView(patient.cpf), fontSize: 10, margin: [0, 4, 0, 4] },
      { text: patient.name, fontSize: 10, margin: [0, 4, 0, 4] },
      { text: calculateAge(patient.birthdate), fontSize: 10, margin: [0, 4, 0, 4] },
      { text: patient.sex, fontSize: 10, margin: [0, 4, 0, 4] },
      { text: conditions, fontSize: 10, margin: [0, 4, 0, 4] }
    ]
  });

  console.log(data);

  /* Conteúdo do relatório */
  const details = [
    {
      table: {
        headerRows: 1,
        widths: ["*", "*", "*", "*", "*"],
        body: [
          [
            { text: 'CPF', style: 'tableHeader' },
            { text: 'Nome', style: 'tableHeader' },
            { text: 'Idade', style: 'tableHeader' },
            { text: 'Sexo', style: 'tableHeader' },
            { text: 'Condição de Saúde', style: 'tableHeader' }
          ],
          ...data
        ]
      },
      layout: "lightHorizontalLines"
    }
  ] as TDocumentDefinitions["content"];

  /* Rodapé */
  const footer = function (currentPage, pageCount) {
    return [
      {
        text: "Página " + currentPage.toString() + " de " + pageCount,
        fontSize: 10,
        alignment: "right",
        margin: [0, 10, 20, 0]
      }
    ];
  } as TDocumentDefinitions["footer"];

  const docDefinitions = {
    pageSize: 'A4',
    pageMargins: [15, 50, 15, 40], /*left, top, right, bottom*/

    header: reportTitle,

    content: details,

    footer: footer,
  } as TDocumentDefinitions;


  pdfMake.createPdf(docDefinitions).open();

}

export { patientReportPDF };