import { Navigate, Route, Routes } from 'react-router-dom';
import { useAuth } from "../context/AuthContext";

/* Configurações de Rotas */
import { PrivateRoutes } from './PrivateRoutes';
import { AdminRoutes } from './AdminRoutes';

/* Páginas */
import { Login } from "../pages/Login";
import { Dashboard } from "../pages/Dashboard";
import { CreateAgents } from '../pages/Agents/CreateAgents';
import { ListAgents } from '../pages/Agents/ListAgents';
import { UpdateAgents } from '../pages/Agents/UpdateAgents';
import { CreateConditions } from '../pages/Conditions/CreateConditions';
import { ListConditions } from '../pages/Conditions/ListConditions';
import { UpdateConditions } from '../pages/Conditions/UpdateConditions';
import { CreateMicroareas } from '../pages/Microareas/CreateMicroareas';
import { ListMicroareas } from '../pages/Microareas/ListMicroareas';
import { CreatePatients } from '../pages/Patients/CreatePatients';
import { ListPatients } from '../pages/Patients/ListPatients';
import { UpdatePatients } from '../pages/Patients/UpdatePatients';
import { SearchPatients } from '../pages/Patients/SearchPatients';
import { UpdateMicroareas } from '../pages/Microareas/UpdateMicroareas';

function Router() {
  const { signed } = useAuth();
  return (
    <Routes>
      <Route path="/" element={!signed ? <Login /> : <Navigate to='/dashboard' />} />
      <Route element={<PrivateRoutes />}>
        <Route path="/dashboard" element={<Dashboard />} />
        <Route path="/patients/create" element={<CreatePatients />} />
        <Route path="/patients/list" element={<ListPatients />} />
        <Route path="/patients/update/:id" element={<UpdatePatients />} />

        <Route element={<AdminRoutes />}>
          <Route path="/agents/create" element={<CreateAgents />} />
          <Route path="/agents/list" element={<ListAgents />} />
          <Route path="/agents/update/:id" element={<UpdateAgents />} />

          <Route path="/conditions/create" element={<CreateConditions />} />
          <Route path="/conditions/list" element={<ListConditions />} />
          <Route path="/conditions/update/:id" element={<UpdateConditions />} />

          <Route path="/microareas/create" element={<CreateMicroareas />} />
          <Route path="/microareas/list" element={<ListMicroareas />} />
          <Route path="/microareas/update/:id" element={<UpdateMicroareas />} />

          <Route path="/patients/search" element={<SearchPatients />} />
        </Route>
      </Route>

    </Routes>
  );
}

export { Router };